@@ -6,7 +6,7 @@ use MooX::Options prefer_commandline => 1;
 use IO::All;
 use Bioinfo::PBS::Queue;
 
-our $VERSION = '0.1.11'; # VERSION: 
+our $VERSION = '0.1.12'; # VERSION: 
 # ABSTRACT: submit blast after splitting a fasta file into multiple files;
 
 
@@ -64,6 +64,16 @@ option cpu => (
 );
 
 
+option max_target_seqs => (
+  is => 'ro',
+  format => 'i',
+  short => 'm',
+  default => sub { '10000' },
+  doc => "max_target_seqs"
+);
+
+
+
 option outdir => (
   is => 'ro',
   format => 's',
@@ -141,6 +151,7 @@ sub execute {
 sub submit_pbs {
   my $self = shift;
   my ($input, $outdir, $cpu, $db) = ($self->input, $self->outdir, $self->cpu, $self->db);
+  my $max_target_seqs = $self->max_target_seqs;
   my @io_fas = io("$outdir")->filter( sub {
       $_->filename =~/\.fa/;
     }
@@ -207,7 +218,7 @@ Bioinfo::App::Cmd::Blast::Cmd::SplitSubmit - submit blast after splitting a fast
 
 =head1 VERSION
 
-version 0.1.11
+version 0.1.12
 
 =head1 SYNOPSIS
 
@@ -239,6 +250,8 @@ the database that blast will use
 
 =head2 cpu
 
+=head2 max_target_seqs
+
 =head2 outdir
 
 =head2 prefix
